@@ -10,12 +10,13 @@ from media_platform.service.media_platform_request import MediaPlatformRequest
 class UploadConfigurationRequest(MediaPlatformRequest):
     def __init__(self, authenticated_http_client: AuthenticatedHTTPClient, base_url: str):
         super().__init__(authenticated_http_client, 'POST', base_url + '/v3/upload/configuration', UploadConfiguration)
-        self.path = None
         self.bucket = None
-        self.mime_type = None
+        self.path = None
         self.acl = None
+        self.mime_type = None
         self.size = None
         self.callback = None
+        self.protocol = None
 
     def set_path(self, path: str) -> UploadConfigurationRequest:
         self.path = path
@@ -41,6 +42,10 @@ class UploadConfigurationRequest(MediaPlatformRequest):
         self.callback = callback
         return self
 
+    def set_protocol(self, protocol: str) -> UploadConfigurationRequest:
+        self.protocol = protocol
+        return self
+
     def execute(self) -> UploadConfiguration:
         return super().execute()
 
@@ -55,5 +60,6 @@ class UploadConfigurationRequest(MediaPlatformRequest):
             'mimeType': self.mime_type,
             'size': self.size,
             'acl': self.acl,
-            'callback': self.callback.serialize() if self.callback else None
+            'callback': self.callback.serialize() if self.callback else None,
+            'protocol': self.protocol
         }
